=======
History
=======


0.5.1 (2018-7-9)
------------------

* tornado 5.0.0+ compatible

0.5.0 (2018-6-12)
------------------

* python3 compatible

0.4.0 (2018-5-23)
------------------

* rewrite directive parser, fix an issue when EOL is in MP3 octet-stream
* add a new recorder using ALSA arecord as lots of forks reported that they were confused by the log of pyaudio (portaudio)

0.3.0 (2018-5-21)
------------------

* bugfix

0.2.2 (2018-3-29)
------------------

* fix gstreamer doesn't release audio device after end-of-stream

0.2.1 (2018-3-28)
------------------

* use gstreamer as the default audio player as gstreamer works better that others on raspberry pi

0.2.0 (2018-3-28)
------------------

* support using mpg123 or mpv as player

0.1.1 (2017-12-29)
------------------

* bugfix

0.1.0 (2017-12-27)
------------------

* support TuneIn audio stream
* add alexa-audio-check util

0.0.9 (2017-09-29)
------------------

* add LED light for respeaker core and respeaker usb mic array
* add inactive time report event

0.0.8 (2017-09-25)
------------------

* limit audio queue length, fix string to invalid filename

0.0.7 (2017-08-31)
------------------

* able to handle a few kind of connection failures and do reconnection

0.0.6 (2017-08-30)
------------------

* fix dueros oauth invalid access token issue
* fix dueros-auth

0.0.5 (2017-08-24)
------------------

* support alerts interface

0.0.4 (2017-07-13)
------------------

* add hands free alexa util using respeaker python library

0.0.3 (2017-07-11)
------------------

* use gstreamer to play audio stream
* support dueros avs compatible service
* many improments

0.0.2 (2017-07-05)
------------------

* rename alexa util to alexa-tap
* add oauth util alexa-auth

0.0.1 (2017-07-04)
------------------

* First release on PyPI.
